@@ -30,3 +30,16 @@ def squareOfANumber(number):
 def division(Divisor,Dividend):
     result = 'the quotient is: %s'% (Dividend/Divisor)
     return result
+def divisionOne(Dividend):
+    result = 'the quotient is: %s'% (Dividend/1)
+    return result
+def toThePowerOfNumber_positiveNumber(number,Power):
+    num_sqrt = number ** Power
+    copiseded_number = ' %0.3f 的 %0.3f 次方为 %0.3f'%(number,Power,num_sqrt)
+    return copiseded_number
+def toThePowerOfNumber_negativeNumber(number,Power):
+    num_sqrt = number ** Power
+    copiseded_numbertimes = '{0} 的 {1:0.3f}次方为 {2:0.3f}+{3:0.3f}j'.format(number,Power,
+    num_sqrt.real,num_sqrt.imag)
+    return copiseded_numbertimes
+
